@@ -100,6 +100,7 @@ __all__ = (
     "DescribeDhcpOptionsPaginatorName",
     "DescribeEgressOnlyInternetGatewaysPaginatorName",
     "DescribeExportImageTasksPaginatorName",
+    "DescribeFastLaunchImagesPaginatorName",
     "DescribeFastSnapshotRestoresPaginatorName",
     "DescribeFleetsPaginatorName",
     "DescribeFlowLogsPaginatorName",
@@ -206,6 +207,8 @@ __all__ = (
     "ExportTaskCancelledWaiterName",
     "ExportTaskCompletedWaiterName",
     "ExportTaskStateType",
+    "FastLaunchResourceTypeType",
+    "FastLaunchStateCodeType",
     "FastSnapshotRestoreStateCodeType",
     "FindingsFoundType",
     "FleetActivityStatusType",
@@ -263,6 +266,7 @@ __all__ = (
     "InstanceMetadataEndpointStateType",
     "InstanceMetadataOptionsStateType",
     "InstanceMetadataProtocolStateType",
+    "InstanceMetadataTagsStateType",
     "InstanceRunningWaiterName",
     "InstanceStateNameType",
     "InstanceStatusOkWaiterName",
@@ -295,6 +299,8 @@ __all__ = (
     "LaunchTemplateInstanceMetadataEndpointStateType",
     "LaunchTemplateInstanceMetadataOptionsStateType",
     "LaunchTemplateInstanceMetadataProtocolIpv6Type",
+    "LaunchTemplateInstanceMetadataTagsStateType",
+    "ListImagesInRecycleBinPaginatorName",
     "ListSnapshotsInRecycleBinPaginatorName",
     "ListingStateType",
     "ListingStatusType",
@@ -528,6 +534,12 @@ CapacityReservationInstancePlatformType = Literal[
     "Linux with SQL Server Standard",
     "Linux with SQL Server Web",
     "Linux/UNIX",
+    "RHEL with HA",
+    "RHEL with HA and SQL Server Enterprise",
+    "RHEL with HA and SQL Server Standard",
+    "RHEL with SQL Server Enterprise",
+    "RHEL with SQL Server Standard",
+    "RHEL with SQL Server Web",
     "Red Hat Enterprise Linux",
     "SUSE Linux",
     "Windows",
@@ -590,6 +602,7 @@ DescribeCoipPoolsPaginatorName = Literal["describe_coip_pools"]
 DescribeDhcpOptionsPaginatorName = Literal["describe_dhcp_options"]
 DescribeEgressOnlyInternetGatewaysPaginatorName = Literal["describe_egress_only_internet_gateways"]
 DescribeExportImageTasksPaginatorName = Literal["describe_export_image_tasks"]
+DescribeFastLaunchImagesPaginatorName = Literal["describe_fast_launch_images"]
 DescribeFastSnapshotRestoresPaginatorName = Literal["describe_fast_snapshot_restores"]
 DescribeFleetsPaginatorName = Literal["describe_fleets"]
 DescribeFlowLogsPaginatorName = Literal["describe_flow_logs"]
@@ -730,6 +743,10 @@ ExportEnvironmentType = Literal["citrix", "microsoft", "vmware"]
 ExportTaskCancelledWaiterName = Literal["export_task_cancelled"]
 ExportTaskCompletedWaiterName = Literal["export_task_completed"]
 ExportTaskStateType = Literal["active", "cancelled", "cancelling", "completed"]
+FastLaunchResourceTypeType = Literal["snapshot"]
+FastLaunchStateCodeType = Literal[
+    "disabling", "disabling-failed", "enabled", "enabled-failed", "enabling", "enabling-failed"
+]
 FastSnapshotRestoreStateCodeType = Literal[
     "disabled", "disabling", "enabled", "enabling", "optimizing"
 ]
@@ -842,6 +859,7 @@ InstanceMatchCriteriaType = Literal["open", "targeted"]
 InstanceMetadataEndpointStateType = Literal["disabled", "enabled"]
 InstanceMetadataOptionsStateType = Literal["applied", "pending"]
 InstanceMetadataProtocolStateType = Literal["disabled", "enabled"]
+InstanceMetadataTagsStateType = Literal["disabled", "enabled"]
 InstanceRunningWaiterName = Literal["instance_running"]
 InstanceStateNameType = Literal[
     "pending", "running", "shutting-down", "stopped", "stopping", "terminated"
@@ -945,6 +963,7 @@ InstanceTypeType = Literal[
     "c6i.4xlarge",
     "c6i.8xlarge",
     "c6i.large",
+    "c6i.metal",
     "c6i.xlarge",
     "cc1.4xlarge",
     "cc2.8xlarge",
@@ -1005,6 +1024,7 @@ InstanceTypeType = Literal[
     "h1.4xlarge",
     "h1.8xlarge",
     "hi1.4xlarge",
+    "hpc6a.48xlarge",
     "hs1.8xlarge",
     "i2.2xlarge",
     "i2.4xlarge",
@@ -1153,6 +1173,7 @@ InstanceTypeType = Literal[
     "m6i.4xlarge",
     "m6i.8xlarge",
     "m6i.large",
+    "m6i.metal",
     "m6i.xlarge",
     "mac1.metal",
     "p2.16xlarge",
@@ -1253,6 +1274,16 @@ InstanceTypeType = Literal[
     "r6gd.medium",
     "r6gd.metal",
     "r6gd.xlarge",
+    "r6i.12xlarge",
+    "r6i.16xlarge",
+    "r6i.24xlarge",
+    "r6i.2xlarge",
+    "r6i.32xlarge",
+    "r6i.4xlarge",
+    "r6i.8xlarge",
+    "r6i.large",
+    "r6i.metal",
+    "r6i.xlarge",
     "t1.micro",
     "t2.2xlarge",
     "t2.large",
@@ -1311,6 +1342,12 @@ InstanceTypeType = Literal[
     "x2gd.medium",
     "x2gd.metal",
     "x2gd.xlarge",
+    "x2iezn.12xlarge",
+    "x2iezn.2xlarge",
+    "x2iezn.4xlarge",
+    "x2iezn.6xlarge",
+    "x2iezn.8xlarge",
+    "x2iezn.metal",
     "z1d.12xlarge",
     "z1d.2xlarge",
     "z1d.3xlarge",
@@ -1391,6 +1428,8 @@ LaunchTemplateHttpTokensStateType = Literal["optional", "required"]
 LaunchTemplateInstanceMetadataEndpointStateType = Literal["disabled", "enabled"]
 LaunchTemplateInstanceMetadataOptionsStateType = Literal["applied", "pending"]
 LaunchTemplateInstanceMetadataProtocolIpv6Type = Literal["disabled", "enabled"]
+LaunchTemplateInstanceMetadataTagsStateType = Literal["disabled", "enabled"]
+ListImagesInRecycleBinPaginatorName = Literal["list_images_in_recycle_bin"]
 ListSnapshotsInRecycleBinPaginatorName = Literal["list_snapshots_in_recycle_bin"]
 ListingStateType = Literal["available", "cancelled", "pending", "sold"]
 ListingStatusType = Literal["active", "cancelled", "closed", "pending"]
@@ -2028,6 +2067,7 @@ PaginatorName = Literal[
     "describe_dhcp_options",
     "describe_egress_only_internet_gateways",
     "describe_export_image_tasks",
+    "describe_fast_launch_images",
     "describe_fast_snapshot_restores",
     "describe_fleets",
     "describe_flow_logs",
@@ -2128,6 +2168,7 @@ PaginatorName = Literal[
     "get_transit_gateway_route_table_associations",
     "get_transit_gateway_route_table_propagations",
     "get_vpn_connection_device_types",
+    "list_images_in_recycle_bin",
     "list_snapshots_in_recycle_bin",
     "search_local_gateway_routes",
     "search_transit_gateway_multicast_groups",
